@@ -1,6 +1,3 @@
-#!/usr/bin/env python
-# coding=utf-8
-
 SYMBOL_TYPE_SPOT = 'SPOT'
 
 ORDER_STATUS_NEW = 'NEW'
@@ -32,14 +29,29 @@ SIDE_SELL = 'SELL'
 
 ORDER_TYPE_LIMIT = 'LIMIT'
 ORDER_TYPE_MARKET = 'MARKET'
+ORDER_TYPE_STOP_LOSS = 'STOP_LOSS'
+ORDER_TYPE_STOP_LOSS_LIMIT = 'STOP_LOSS_LIMIT'
+ORDER_TYPE_TAKE_PROFIT = 'TAKE_PROFIT'
+ORDER_TYPE_TAKE_PROFIT_LIMIT = 'TAKE_PROFIT_LIMIT'
+ORDER_TYPE_LIMIT_MAKER = 'LIMIT_MAKER'
+
+FUTURE_ORDER_TYPE_LIMIT = 'LIMIT'
+FUTURE_ORDER_TYPE_MARKET = 'MARKET'
+FUTURE_ORDER_TYPE_STOP = 'STOP'
+FUTURE_ORDER_TYPE_STOP_MARKET = 'STOP_MARKET'
+FUTURE_ORDER_TYPE_TAKE_PROFIT = 'TAKE_PROFIT'
+FUTURE_ORDER_TYPE_TAKE_PROFIT_MARKET = 'TAKE_PROFIT_MARKET'
+FUTURE_ORDER_TYPE_LIMIT_MAKER = 'LIMIT_MAKER'
 
 TIME_IN_FORCE_GTC = 'GTC'  # Good till cancelled
 TIME_IN_FORCE_IOC = 'IOC'  # Immediate or cancel
+TIME_IN_FORCE_FOK = 'FOK'  # Fill or kill
+TIME_IN_FORCE_GTX = 'GTX'  # Post only order
 
-WEBSOCKET_UPDATE_0SECOND = '0ms'
-WEBSOCKET_UPDATE_1SECOND = '1000ms'
+ORDER_RESP_TYPE_ACK = 'ACK'
+ORDER_RESP_TYPE_RESULT = 'RESULT'
+ORDER_RESP_TYPE_FULL = 'FULL'
 
-WEBSOCKET_DEPTH_1 = '1'
 WEBSOCKET_DEPTH_5 = '5'
 WEBSOCKET_DEPTH_10 = '10'
 WEBSOCKET_DEPTH_20 = '20'
